@@ -1,7 +1,6 @@
 import os
 
 from CleanEmonPopulator import PACKAGE_DIR
-from CleanEmonPopulator import DATA_DIR
 from CleanEmonPopulator import CONFIG_FILE
 from CleanEmonPopulator import SCHEMA_FILE
 
@@ -10,9 +9,6 @@ def test_dirs():
     assert os.path.exists(PACKAGE_DIR)
     assert os.path.isdir(PACKAGE_DIR)
 
-    assert os.path.exists(DATA_DIR)
-    assert os.path.isdir(DATA_DIR)
-
 
 def test_files():
     assert os.path.exists(CONFIG_FILE)
